@@ -52,11 +52,11 @@
 #'
 #' where \eqn{\left[{}^{206}Pb/{}^{204}Pb\right]_{3.7Ga} = 11.152} and
 #' \eqn{\left[{}^{238}U/{}^{204}Pb\right]_{sk} = 9.74}. These
-#' Equations can be solved iteratively for \eqn{t} and
-#' \eqn{\left[{}^{206}Pb/{}^{204}Pb\right]_\circ}. The
-#' \eqn{{}^{207}}Pb/\eqn{{}^{204}}Pb-ratio is corrected in exactly the
-#' same way, using \eqn{\left[{}^{207}Pb/{}^{204}Pb\right]_{3.7Ga} =
-#' 12.998}.
+#' Equations can be solved for \eqn{t} and
+#' \eqn{\left[{}^{206}Pb/{}^{204}Pb\right]_\circ} using the method of
+#' maximum likelihood. The \eqn{{}^{207}}Pb/\eqn{{}^{204}}Pb-ratio is
+#' corrected in exactly the same way, using
+#' \eqn{\left[{}^{207}Pb/{}^{204}Pb\right]_{3.7Ga} = 12.998}.
 #'
 #' In the absence of \eqn{^{204}}Pb measurements, a \eqn{^{208}}Pb-based
 #' common lead correction can be used:
@@ -101,12 +101,12 @@
 #'
 #' @param option one of either
 #' 
-#' \code{1}: Stacey-Kramers correction
-#' 
+#' \code{1}: nominal common Pb isotope composition
+#'
 #' \code{2}: isochron regression
 #'
-#' \code{3}: nominal common Pb isotope composition
-#'
+#' \code{3}: Stacey-Kramers correction
+#' 
 #' @param omit vector with indices of aliquots that should be omitted
 #'     from the isochron regression (only used if \code{option=2})
 #'
@@ -120,27 +120,27 @@
 #' ages. Geochimica et Cosmochimica Acta, 62(4), pp.665-676.
 #' 
 #' Stacey, J.T. and Kramers, 1., 1975. Approximation of terrestrial
-#' lead isotope evolution by a two-stage model. Earth and planetary
-#' science letters, 26(2), pp.207-221.
+#' lead isotope evolution by a two-stage model. Earth and Planetary
+#' Science Letters, 26(2), pp.207-221.
 #' 
 #' @examples
 #' data(examples)
-#' UPb <- Pb0corr(examples$UPb,option=1)
+#' UPb <- Pb0corr(examples$UPb,option=2)
 #' concordia(UPb)
 #' # produces identical results as:
 #' dev.new()
-#' concordia(examples$UPb,common.Pb=1)
+#' concordia(examples$UPb,common.Pb=2)
 #' @export
-Pb0corr <- function(x,option=1,omit=NULL){
+Pb0corr <- function(x,option=3,omit=NULL){
     ns <- length(x)
     out <- x
     out$x.raw <- x$x
     if (option == 1){
-        x.corr <- common.Pb.stacey.kramers(x)
+        x.corr <- common.Pb.nominal(x)
     } else if (option == 2){
         x.corr <- common.Pb.isochron(x,omit=omit)
     } else if (option == 3){
-        x.corr <- common.Pb.nominal(x)
+        x.corr <- common.Pb.stacey.kramers(x)
     } else {
         return
     }
@@ -329,18 +329,17 @@ common.Pb.stacey.kramers <- function(x){
             tint <- stats::optimise(SS.SK.without.204,
                                     interval=c(0,5000),x=x,i=i)$minimum
             i6474 <- stacey.kramers(tint)
-            c76 <- i6474['i74']/i6474['i64']
+            c76 <- i6474[,'i74']/i6474[,'i64']
             out[i,] <- correct.common.Pb.without.204(x,i,c76,lower=FALSE)
         }
     } else if (x$format %in% c(4,5,6)){
         out <- matrix(0,ns,5)
         colnames(out) <- c('Pb207U235','errPb207U235','Pb206U238','errPb206U238','rho')
         for (i in 1:ns){
-            tint <- stats::optimise(SS.SK.with.204,
-                                    interval=c(0,5000),x=x,i=i)$minimum
+            tint <- stats::optimise(SS.SK.with.204,interval=c(0,5000),x=x,i=i)$minimum
             c6474 <- stacey.kramers(tint)
-            c46 <- 1/c6474['i64']
-            c47 <- 1/c6474['i74']
+            c46 <- 1/c6474[,'i64']
+            c47 <- 1/c6474[,'i74']
             out[i,] <- correct.common.Pb.with.204(x,i,c46,c47)
         }
     } else if (x$format %in% c(7,8)){
@@ -352,8 +351,8 @@ common.Pb.stacey.kramers <- function(x){
             tint <- stats::optimise(SS.SK.with.208,
                                     interval=c(0,5000),x=x,i=i)$minimum
             c678 <- stacey.kramers(tint)
-            c86 <- c678['i84']/c678['i64']
-            c87 <- c678['i84']/c678['i74']
+            c86 <- c678[,'i84']/c678[,'i64']
+            c87 <- c678[,'i84']/c678[,'i74']
             out[i,] <- correct.common.Pb.with.208(x,i=i,tt=tint,c0806=c86,c0807=c87)
         }
     }
@@ -464,8 +463,8 @@ SS.SK.without.204 <- function(tt,x,i){
 SS.SK.with.204 <- function(tt,x,i){
     wi <- wetherill(x,i=i)
     i6474 <- stacey.kramers(tt)
-    i64 <- i6474['i64']
-    i74 <- i6474['i74']
+    i64 <- i6474[1,'i64']
+    i74 <- i6474[1,'i74']
     U <- iratio('U238U235')[1]
     ccw <- list(x=rep(0,2),cov=matrix(0,2,2))
     cnames <- c('Pb207U235','Pb206U238')
@@ -546,13 +545,63 @@ stacey.kramers <- function(tt,inverse=FALSE){
     i84 <- sk.208.204 + sk.232.204*(exp(l2*ti)-exp(l2*tt))
     if (inverse){ # for Pb-Pb data
         out <- cbind(1/i64,i74/i64,i84/64)
-        names(out) <- c('i46','i76','i86')
+        colnames(out) <- c('i46','i76','i86')
     } else {
         out <- cbind(i64,i74,i84)
-        names(out) <- c('i64','i74','i84')
+        colnames(out) <- c('i64','i74','i84')
     }
     out
 }
+# TODO: add option for Pb207Pb206 ratios to be used with inverse isochrons
+sk2t <- function(Pb206Pb204=rep(NA,2),Pb207Pb204=rep(NA,2)){
+    l5 <- lambda('U235')[1]
+    l8 <- lambda('U238')[1]
+    ti.young <- 3700
+    sk.206.204.young <- 11.152
+    sk.207.204.young <- 12.998
+    sk.208.204.young <- 31.23
+    sk.238.204.young <- 9.74
+    sk.232.204.young <- 36.84
+    ti.old <- 4570
+    sk.206.204.old <- 9.307
+    sk.207.204.old <- 10.294
+    sk.208.204.old <- 29.487
+    sk.238.204.old <- 7.19
+    sk.232.204.old <- 33.21
+    l5 <- lambda('U235')[1]
+    l8 <- lambda('U238')[1]
+    U <- iratio('U238U235')[1]
+    out <- c(0,ti.old)
+    # 1. 206/204
+    min64 <- sk.206.204.old
+    max64 <- sk.206.204.young+sk.238.204.young*(exp(l8*ti.young)-1)
+    good64 <- !is.na(Pb206Pb204)
+    big64 <- good64 & (Pb206Pb204>max64)
+    small64 <- good64 & (Pb206Pb204<min64)
+    mid64 <- good64 & !big64 & !small64
+    out[big64] <- 0
+    out[small64] <- ti.old
+    out[mid64] <- log( exp(l8*ti.young) +
+                       (sk.206.204.young-Pb206Pb204[mid64])/sk.238.204.young )/l8
+    if (any(mid64) && out[mid64]>ti.young)
+        out[mid64] <- log( exp(l8*ti.old) +
+                           (sk.206.204.old-Pb206Pb204[mid64])/sk.238.204.old )/l8
+    # 2. 207/204
+    min74 <- sk.207.204.old
+    max74 <- sk.207.204.young + sk.238.204.young*(exp(l5*ti.young)-1)/U
+    good74 <- !is.na(Pb207Pb204)
+    big74 <- good74 & (Pb207Pb204>max74)
+    small74 <- good74 & (Pb207Pb204<min74)
+    mid74 <- good74 & !big74 & !small74
+    out[big74] <- 0
+    out[small74] <- ti.old
+    out[mid74] <- log( exp(l5*ti.young) +
+                       U*(sk.207.204.young-Pb207Pb204[mid74])/sk.238.204.young )/l5
+    if (any(mid74) && out[mid74]>ti.young)
+        out[mid74] <- log( exp(l5*ti.old) +
+                           (sk.207.204.old-Pb207Pb204[mid74])/sk.238.204.old )/l5
+    out
+}
 
 project.concordia <- function(m86,m76,c76,d=diseq(),lower=TRUE){
     t68 <- get.Pb206U238.age(1/m86,d=d)[1]
