@@ -3,37 +3,37 @@
 concordia.intersection.ludwig <- function(x,wetherill=TRUE,exterr=FALSE,alpha=0.05,
                                           model=1,anchor=list(FALSE,NA)){
     fit <- ludwig(x,exterr=exterr,model=model,anchor=anchor)
-    out <- list()
-    out$model <- model
-    out$mswd <- fit$mswd
-    out$w <- fit$w
-    out$p.value <- fit$p.value
+    out <- fit
     out$fact <- tfact(alpha,fit$df)
     out$format <- x$format
     if (wetherill){
-        out <- c(out,twfit2wfit(fit,x))
-        names(out$x) <- c('t[l]','t[u]')
+        wfit <- twfit2wfit(fit,x)
+        out$par <- wfit$par
+        out$cov <- wfit$cov
+        names(out$par) <- c('t[l]','t[u]')
     } else {
-        out$x <- fit$par
+        out$par <- fit$par
         out$cov <- fit$cov
     }
+    np <- length(out$par)
     if (model==1 && fit$mswd>1){
-        out$err <- matrix(NA,3,length(out$x))
+        out$err <- matrix(NA,3,np)
         rownames(out$err) <- c('s','ci','disp')
         out$err['disp',] <-
             out$fact*sqrt(fit$mswd)*sqrt(diag(out$cov))
     } else {
-        out$err <- matrix(NA,2,length(out$x))
+        out$err <- matrix(NA,2,np)
         rownames(out$err) <- c('s','ci')
     }
     if (model==3) out$fact <- nfact(alpha)
     out$err['s',] <- sqrt(diag(out$cov))
     out$err['ci',] <- out$fact*out$err['s',]
-    colnames(out$err) <- names(out$x)
+    colnames(out$err) <- names(out$par)
     out
 }
 # extracts concordia intersection parameters from an ordinary York fit
-concordia.intersection.ab <- function(a,b,exterr=FALSE,wetherill=FALSE,d=diseq()){
+concordia.intersection.ab <- function(a,b,covmat=matrix(0,2,2),
+                                      exterr=FALSE,wetherill=FALSE,d=diseq()){
     l8 <- lambda('U238')[1]
     ta <- get.Pb207Pb206.age(a,d=d)[1]
     out <- c(1,a) # tl, 7/6 intercept
@@ -67,7 +67,7 @@ concordia.intersection.ab <- function(a,b,exterr=FALSE,wetherill=FALSE,d=diseq()
 # extract the lower and upper discordia intercept from the parameters
 # of a Ludwig fit (initial Pb ratio and lower intercept age)
 twfit2wfit <- function(fit,x){
-    tt <- fit$par[1]
+    tt <- fit$par['t']
     buffer <- 1 # start searching 1Ma above or below first intercept age
     l5 <- lambda('U235')[1]
     l8 <- lambda('U238')[1]
@@ -77,15 +77,15 @@ twfit2wfit <- function(fit,x){
     if (x$format %in% c(1,2,3)){
         a0 <- 1
         b0 <- fit$par['76i']
-        E[c(1,3),c(1,3)] <- fit$cov
+        E[c(1,3),c(1,3)] <- fit$cov[1:2,1:2]
     } else if (x$format %in% c(4,5,6)){
         a0 <- fit$par['64i']
         b0 <- fit$par['74i']
-        E <- fit$cov
+        E <- fit$cov[1:3,1:3]
     } else if (x$format %in% c(7,8)){
         a0 <- fit$par['68i']
         b0 <- fit$par['78i']
-        E <- fit$cov
+        E <- fit$cov[1:3,1:3]
     } else {
         stop('Incorrect input format')
     }
@@ -98,8 +98,6 @@ twfit2wfit <- function(fit,x){
                              t2=tt,a0=a0,b0=b0,d=x$d)$root
     } else {
         search.range <- c(-1000,tt-buffer)
-        if (x$d$U48$option>0) # disequilibrium samples
-            search.range[1] <- -0.001/settings('lambda','U234')[1]
         tl <- stats::uniroot(intersection.misfit.ludwig,interval=search.range,
                              t2=tt,a0=a0,b0=b0,d=x$d)$root
         tu <- tt
@@ -132,7 +130,7 @@ twfit2wfit <- function(fit,x){
         J[2,1] <- 1
     }
     out <- list()
-    out$x <- c(tl,tu)
+    out$par <- c(tl,tu)
     out$cov <- J %*% E %*% t(J)
     out
 }
@@ -154,13 +152,27 @@ intersection.misfit.ludwig <- function(t1,t2,a0,b0,d=diseq()){
     YY - BB*XX
 }
 # a = intercept, b = slope on TW concordia
-intersection.misfit.york <- function(tt,a,b,d=diseq()){
+intersection.misfit.york <- function(tt,a,b,covmat=NULL,d=diseq()){
     l5 <- lambda('U235')[1]
     l8 <- lambda('U238')[1]
     U <- iratio('U238U235')[1]
     D <- mclean(tt=tt,d=d)
     # misfit is based on difference in slope in TW space
-    D$Pb207U235/U - a*D$Pb206U238 - b
+    m <- D$Pb207U235/U - a*D$Pb206U238 - b
+    if (is.null(covmat)){
+        return(m)
+    } else { # error propagation
+        dmda <- -D$Pb206U238
+        dmdb <- -1
+        dmdt <- D$dPb207U235dt/U - a*D$dPb206U238dt
+        dtda <- -dmda/dmdt # implicit differentiation
+        dtdb <- -dmdb/dmdt
+        J <- matrix(0,2,2)
+        J[1,1] <- dtda
+        J[1,2] <- dtdb
+        J[2,1] <- 1    # dada
+        return(J%*%covmat%*%t(J))
+    }
 }
 
 discordia.line <- function(fit,wetherill,d=diseq()){
@@ -171,10 +183,10 @@ discordia.line <- function(fit,wetherill,d=diseq()){
     J <- matrix(0,1,2)
     usr <- graphics::par('usr')
     if (wetherill){
-        tl <- fit$x[1]
-        tu <- fit$x[2]
-        X <- age_to_Pb207U235_ratio(fit$x,d=d)[,'75']
-        Y <- age_to_Pb206U238_ratio(fit$x,d=d)[,'68']
+        tl <- fit$par[1]
+        tu <- fit$par[2]
+        X <- age_to_Pb207U235_ratio(fit$par,d=d)[,'75']
+        Y <- age_to_Pb206U238_ratio(fit$par,d=d)[,'68']
         x <- seq(from=max(0,usr[1],X[1]),to=min(usr[2],X[2]),length.out=50)
         du <- mclean(tt=tu,d=d)
         dl <- mclean(tt=tl,d=d)
@@ -207,15 +219,15 @@ discordia.line <- function(fit,wetherill,d=diseq()){
         ciy <- c(ll,rev(ul))
     } else {
         fit2d <- tw3d2d(fit)
-        X[1] <- age_to_U238Pb206_ratio(fit2d$x['t'],d=d)[,'86']
-        Y[1] <- age_to_Pb207Pb206_ratio(fit2d$x['t'],d=d)[,'76']
-        r75 <- age_to_Pb207U235_ratio(fit2d$x['t'],d=d)[,'75']
+        X[1] <- age_to_U238Pb206_ratio(fit2d$par['t'],d=d)[,'86']
+        Y[1] <- age_to_Pb207Pb206_ratio(fit2d$par['t'],d=d)[,'76']
+        r75 <- age_to_Pb207U235_ratio(fit2d$par['t'],d=d)[,'75']
         r68 <- 1/X[1]
-        Y[2] <- fit2d$x['76i']
+        Y[2] <- fit2d$par['76i']
         xl <- X[1]
         yl <- Y[1]
         y0 <- Y[2]
-        tl <- check.zero.UPb(fit2d$x['t'])
+        tl <- check.zero.UPb(fit2d$par['t'])
         U <- settings('iratio','U238U235')[1]
         nsteps <- 100
         x <- seq(from=max(.Machine$double.xmin,usr[1]),to=usr[2],length.out=nsteps)
@@ -252,16 +264,16 @@ discordia.line <- function(fit,wetherill,d=diseq()){
 }
 
 tw3d2d <- function(fit){
-    out <- list(x=fit$x,cov=fit$cov,fact=fit$fact)
+    out <- list(par=fit$par,cov=fit$cov,fact=fit$fact)
     if (fit$format > 3){
         labels <- c('t','76i')
-        out$x <- c(fit$x['t'],fit$x[3]/fit$x[2]) # x[2] = Pb206i, x[3] = Pb207i
+        out$par <- c(fit$par['t'],fit$par[3]/fit$par[2]) # par[2] = Pb206i, par[3] = Pb207i
         J <- matrix(0,2,3)
         J[1,1] <- 1
-        J[2,2] <- -fit$x[3]/fit$x[2]^2
-        J[2,3] <- 1/fit$x[2]
-        out$cov <- J %*% fit$cov %*% t(J)
-        names(out$x) <- labels
+        J[2,2] <- -fit$par[3]/fit$par[2]^2
+        J[2,3] <- 1/fit$par[2]
+        out$cov <- J %*% fit$cov[1:3,1:3] %*% t(J)
+        names(out$par) <- labels
         colnames(out$cov) <- labels
     }
     out
@@ -269,7 +281,7 @@ tw3d2d <- function(fit){
 
 # this would be much easier in unicode but that doesn't render in PDF:
 discordia.title <- function(fit,wetherill,sigdig=2,...){
-    lower.age <- roundit(fit$x[1],fit$err[,1],sigdig=sigdig)
+    lower.age <- roundit(fit$par[1],fit$err[,1],sigdig=sigdig)
     if (fit$model==1 && fit$mswd>1){
         args1 <- quote(a%+-%b~'|'~c~'|'~d~u~'(n='*n*')')
         args2 <- quote(a%+-%b~'|'~c~'|'~d~u)
@@ -280,7 +292,7 @@ discordia.title <- function(fit,wetherill,sigdig=2,...){
     list1 <- list(a=lower.age[1],b=lower.age[2],
                   c=lower.age[3],u='Ma',n=fit$n)
     if (wetherill){
-        upper.age <- roundit(fit$x[2],fit$err[,2],sigdig=sigdig)
+        upper.age <- roundit(fit$par[2],fit$err[,2],sigdig=sigdig)
         expr1 <- quote('lower intercept =')
         expr2 <- quote('upper intercept =')
         list2 <- list(a=upper.age[1],b=upper.age[2],c=upper.age[3],u='Ma')
@@ -289,7 +301,7 @@ discordia.title <- function(fit,wetherill,sigdig=2,...){
             list2$d <- upper.age[4]
         }
     } else if (fit$format%in%c(1,2,3)){
-        i76 <- roundit(fit$x['76i'],fit$err[,'76i'],sigdig=sigdig)
+        i76 <- roundit(fit$par['76i'],fit$err[,'76i'],sigdig=sigdig)
         expr1 <- quote('age =')
         expr2 <- quote('('^207*'Pb/'^206*'Pb)'[o]*'=')
         list2 <- list(a=i76[1],b=i76[2],c=i76[3],u='')
@@ -298,8 +310,8 @@ discordia.title <- function(fit,wetherill,sigdig=2,...){
             list2$d <- i76[4]
         }
     } else if (fit$format%in%c(4,5,6)){
-        i64 <- roundit(fit$x['64i'],fit$err[,'64i'],sigdig=sigdig)
-        i74 <- roundit(fit$x['74i'],fit$err[,'74i'],sigdig=sigdig)
+        i64 <- roundit(fit$par['64i'],fit$err[,'64i'],sigdig=sigdig)
+        i74 <- roundit(fit$par['74i'],fit$err[,'74i'],sigdig=sigdig)
         expr1 <- quote('age =')
         expr2 <- quote('('^206*'Pb/'^204*'Pb)'[o]*'=')
         expr3 <- quote('('^207*'Pb/'^204*'Pb)'[o]*'=')
@@ -313,10 +325,10 @@ discordia.title <- function(fit,wetherill,sigdig=2,...){
         call3 <- substitute(e~a,list(e=expr3,a=args2))
         line3 <- do.call('substitute',list(call3,list3))        
     } else if (fit$format%in%c(7,8)){
-        i86 <- 1/fit$x['68i']
-        i87 <- 1/fit$x['78i']
-        i86err <- i86*fit$err[,'68i']/fit$x['68i']
-        i87err <- i87*fit$err[,'78i']/fit$x['78i']
+        i86 <- 1/fit$par['68i']
+        i87 <- 1/fit$par['78i']
+        i86err <- i86*fit$err[,'68i']/fit$par['68i']
+        i87err <- i87*fit$err[,'78i']/fit$par['78i']
         ri86 <- roundit(i86,i86err,sigdig=sigdig)
         ri87 <- roundit(i87,i87err,sigdig=sigdig)
         expr1 <- quote('age =')
@@ -341,11 +353,10 @@ discordia.title <- function(fit,wetherill,sigdig=2,...){
                             list(a=signif(fit$mswd,sigdig),
                                  b=signif(fit$p.value,sigdig)))
     } else if (fit$model==3){
-        rounded.disp <- roundit(100*fit$w[1],100*fit$w[2:3],sigdig=sigdig)
-        line4 <- substitute('overdispersion ='~a+b/-c~'% of Pb'[o],
-                            list(a=rounded.disp[1],
-                                 b=rounded.disp[3],
-                                 c=rounded.disp[2]))        
+        ci <- ci_log2lin_lud(fit=fit,fact=fit$fact)
+        rounded.disp <- roundit(ci[1],ci[2:3],sigdig=sigdig)
+        line4 <- substitute('overdispersion ='~a+b/-c~'Ma',
+                            list(a=rounded.disp[1],b=rounded.disp[3],c=rounded.disp[2]))
     }
     extrarow <- fit$format>3 & !wetherill
     if (fit$model==1 & extrarow){
